@@ -217,6 +217,13 @@ def request(api, options):
         print_response(options, resp)
         resp.raise_for_status()
 
+    elif options['policies']:
+        kwargs = {
+            'query_string': options['query_string_obj'],
+        }
+
+        wrap_obj(options, api.policies_all, **kwargs)
+
     elif options['device-update']:
         resp = api.device_update(
             json=options['json_request_obj'],
@@ -352,6 +359,13 @@ async def aiorequest(api, options):
         await aioprint_response(options, resp)
         resp.raise_for_status()
 
+    elif options['policies']:
+        kwargs = {
+            'query_string': options['query_string_obj'],
+        }
+
+        await aiowrap_obj(options, api.policies_all, **kwargs)
+
     elif options['device-update']:
         resp = await api.device_update(
             json=options['json_request_obj'],
@@ -378,7 +392,33 @@ async def aiorequest(api, options):
         resp.raise_for_status()
 
 
+class GeneratorList(list):
+    def __init__(self, generator, **kwargs):
+        self.name = generator.__name__
+        self.generator = generator(**kwargs)
+
+    def __iter__(self):
+        for ok, x in self.generator:
+            if ok:
+                yield x
+            else:
+                raise ApiError('%s: %s %s: %s' % (
+                    self.name, x.status_code, x.reason, x.text))
+
+    def __len__(self):
+        # ensure list is true
+        return 1
+
+
 def wrap_obj(options, func, **kwargs):
+    if options['opt_json']:
+        # only allowed with noaio
+        bigobj = GeneratorList(generator=func, **kwargs)
+        for x in json.JSONEncoder().iterencode(bigobj):
+            print(x, end='')
+
+        return
+
     obj = {
         'things': []
     }
@@ -573,6 +613,7 @@ def parse_opts():
         'tag': False,
         'profile': False,
         'policy': False,
+        'policies': False,
         'offset': None,
         'pagelength': None,
         'device-update': False,
@@ -587,14 +628,15 @@ def parse_opts():
         'aio': True,
         'print_json': False,
         'print_python': False,
-        'print_jwt': False,
         'jmespath': None,
+        'opt_json': False,
+        'print_jwt': False,
         'timeout': None,
         'debug': 0,
         'dtime': False,
         }
 
-    short_options = 'F:J:jpQ:R:'
+    short_options = 'F:J:jOpQ:R:'
     long_options = [
         'help', 'version', 'debug=', 'dtime',
         'api-version=', 'url=',
@@ -603,7 +645,7 @@ def parse_opts():
         'deviceid=', 'ip=',
         'vuln', 'groupby=', 'vulns',
         'alert', 'alerts',
-        'tag', 'profile', 'policy',
+        'tag', 'profile', 'policy', 'policies',
         'offset=', 'pagelength=',
         'device-update', 'vuln-update', 'alert-update',
         'id=',
@@ -668,6 +710,8 @@ def parse_opts():
             options['profile'] = True
         elif opt == '--policy':
             options['policy'] = True
+        elif opt == '--policies':
+            options['policies'] = True
         elif opt == '--offset':
             options['offset'] = arg
         elif opt == '--pagelength':
@@ -708,6 +752,8 @@ def parse_opts():
                       file=sys.stderr)
                 sys.exit(1)
             options['jmespath'] = arg
+        elif opt == '-O':
+            options['opt_json'] = True
         elif opt == '--jwt':
             options['print_jwt'] = True
         elif opt == '--debug':
@@ -732,6 +778,10 @@ def parse_opts():
         else:
             assert False, 'unhandled option %s' % opt
 
+    if options['opt_json'] and options['aio']:
+        print('Must use --noaio with -O', file=sys.stderr)
+        sys.exit(0)
+
     for x in ['api-version', 'url',
               'access-key-id', 'access-key', 'customerid']:
         if x in options['config'] and options[x] is None:
@@ -812,6 +862,7 @@ def usage():
     --tag                    get tag API request
     --profile                get profile mapping API request
     --policy                 get policy recommendation API request
+    --policies               get all policies
     --offset num             items offset
     --pagelength num         number of items to return
     --device-update          update device API request
@@ -827,6 +878,7 @@ def usage():
     -j                       print JSON
     -p                       print Python
     -J expression            JMESPath expression for JSON response data
+    -O                       optimized get all with JSON only output
     --jwt                    print header, payload from JWT (access key)
     --timeout timeout        connect, read timeout
     -F path                  JSON options (multiple -F's allowed)
