@@ -311,6 +311,8 @@ class IotApi(mixin.Mixin):
             yield x
 
     def tag(self, *,
+            offset=None,
+            pagelength=None,
             query_string=None,
             retry=False):
         path = BASE_PATH + '/tag/list'
@@ -320,6 +322,34 @@ class IotApi(mixin.Mixin):
             'customerid': self.customerid,
             'source': 'tenant',
         }
+        if offset is not None:
+            params['offset'] = offset
+        if pagelength is not None:
+            params['pagelength'] = pagelength
+        if query_string is not None:
+            params.update(query_string)
+
+        kwargs = {
+            'url': url,
+            'params': params,
+        }
+
+        resp = self._request_retry(retry=retry,
+                                   method=self.tag,
+                                   func=self.session.get,
+                                   **kwargs)
+
+        return resp
+
+    def profile(self, *,
+                query_string=None,
+                retry=False):
+        path = BASE_PATH + '/profile/mapping'
+        url = self.url + path
+
+        params = {
+            'customerid': self.customerid,
+        }
         if query_string is not None:
             params.update(query_string)
 
@@ -335,6 +365,47 @@ class IotApi(mixin.Mixin):
 
         return resp
 
+    def policy(self, *,
+               offset=None,
+               pagelength=None,
+               query_string=None,
+               retry=False):
+        path = BASE_PATH + '/policy/recommendation'
+        url = self.url + path
+
+        params = {
+            'customerid': self.customerid,
+        }
+        if offset is not None:
+            params['offset'] = offset
+        if pagelength is not None:
+            params['pagelength'] = pagelength
+        if query_string is not None:
+            params.update(query_string)
+
+        kwargs = {
+            'url': url,
+            'params': params,
+        }
+
+        resp = self._request_retry(retry=retry,
+                                   method=self.tag,
+                                   func=self.session.get,
+                                   **kwargs)
+
+        return resp
+
+    def policies_all(self, *,
+                     query_string=None):
+        kwargs = {
+            'query_string': query_string,
+        }
+
+        for x in self._get_all(func=self.policy,
+                               keys=['policies'],
+                               **kwargs):
+            yield x
+
     def device_update(self, *,
                       json=None,
                       query_string=None,
